@@ -288,7 +288,7 @@ class NordeaAnalyticsService:
 
     def get_bond_static_data(
         self,
-        symbols: Union[List, str],
+        symbols: Union[List[str], str],
         as_df: bool = False,
     ) -> Any:
         """Retrieves latest static data for given ISINs.
@@ -309,8 +309,20 @@ class NordeaAnalyticsService:
         dmb: bool = False,
         country: str = None,
         currency: str = None,
-        issuers: Union[List[Issuers], List[str], Issuers, str] = None,
-        asset_types: Union[List[AssetType], List[str], AssetType, str] = None,
+        issuers: Union[
+            Issuers,
+            str,
+            List[Issuers],
+            List[str],
+            List[Union[Issuers, str]],
+        ] = None,
+        asset_types: Union[
+            AssetType,
+            str,
+            List[AssetType],
+            List[str],
+            List[Union[str, AssetType]],
+        ] = None,
         lower_maturity: datetime = None,
         upper_maturity: datetime = None,
         lower_closing_date: datetime = None,
@@ -321,10 +333,18 @@ class NordeaAnalyticsService:
         upper_outstanding_amount: float = None,
         amortisation_type: Union[AmortisationType, str] = None,
         capital_centres: Union[
-            List[str], str, List[CapitalCentres], CapitalCentres
+            CapitalCentres,
+            str,
+            List[CapitalCentres],
+            List[str],
+            List[Union[CapitalCentres, str]],
         ] = None,
         capital_centre_types: Union[
-            List[str], str, List[CapitalCentreTypes], CapitalCentreTypes
+            CapitalCentreTypes,
+            str,
+            List[CapitalCentreTypes],
+            List[str],
+            List[Union[CapitalCentreTypes, str]],
         ] = None,
         as_df: bool = False,
     ) -> Any:
@@ -391,8 +411,14 @@ class NordeaAnalyticsService:
             List[Union[str, CalculatedBondKeyFigureName]],
         ],
         calc_date: datetime,
-        curves: Union[List[str], str, CurveName, List[CurveName]] = None,
-        rates_shifts: Union[List[str], str] = None,
+        curves: Union[
+            str,
+            CurveName,
+            List[str],
+            List[CurveName],
+            List[Union[str, CurveName]],
+        ] = None,
+        rates_shifts: Union[str, List[str]] = None,
         pp_speed: float = None,
         price: float = None,
         spread: float = None,
@@ -634,7 +660,11 @@ class NordeaAnalyticsService:
         self,
         symbols: Union[str, List[str]],
         keyfigures: Union[
-            List[LiveBondKeyFigureName], List[str], LiveBondKeyFigureName, str
+            LiveBondKeyFigureName,
+            str,
+            List[LiveBondKeyFigureName],
+            List[str],
+            List[Union[LiveBondKeyFigureName, str]],
         ],
         as_df: bool = False,
     ) -> Any:
@@ -659,7 +689,11 @@ class NordeaAnalyticsService:
         self,
         symbols: Union[str, List[str]],
         keyfigures: Union[
-            List[LiveBondKeyFigureName], List[str], LiveBondKeyFigureName, str
+            LiveBondKeyFigureName,
+            str,
+            List[LiveBondKeyFigureName],
+            List[str],
+            List[Union[LiveBondKeyFigureName, str]],
         ],
         as_df: bool = False,
     ) -> Iterator[Any]:
